OiRA

Help

1. Priprema
2. Uključite
3. Prepoznavanje + procjena
4. Plan mjera
5. Završni dokumenti
6. Status 0%

# Procjenu rizika prilagodite vašoj organizaciji

Radi prilagodbe procjene rizika vašoj tvrtki može se od vas zatražiti da:

- odaberete situaciju koja je ili nije značajna za vaše aktivnosti ili preskočite onu koja to nije
- ako postoje, navedete više poslovnih jedinica jer u tom slučaju procjenu rizika morate izraditi za svaku jedinicu ili lokaciju posebno

## Commercial manned guarding

Does your organisation provide commercial manned guarding? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Mobile partrolling/intervention after alarm

Does your organisation provide mobile patrolling / intervention after alarm? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Event security

Does your organisation provide event security? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

Scroll to top
Back

## profiling.html

Više

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More